#-----------------------------------------------------------------------
# File    : nposs.mak
# Contents: commands to build naive possibilistic classifier programs
# Author  : Christian Borgelt
# History : 2003.01.27 file created
#           2006.07.20 adapted to Visual Studio 8
#           2011.12.12 adapted to changed scanner/table reader
#           2016.04.20 completed dependencies on header files
#-----------------------------------------------------------------------
THISDIR  = ..\..\nposs\src
UTILDIR  = ..\..\util\src
TABLEDIR = ..\..\table\src

CC       = cl.exe
DEFS     = /D WIN32 /D NDEBUG /D _CONSOLE /D _CRT_SECURE_NO_WARNINGS
CFLAGS   = /nologo /W3 /O2 /GS- $(DEFS) /c
INCS     = /I $(UTILDIR) /I $(TABLEDIR)

LD       = link.exe
LDFLAGS  = /nologo /subsystem:console /incremental:no
LIBS     = 

HDRS_1   = $(UTILDIR)\fntypes.h    $(UTILDIR)\scanner.h    \
           $(TABLEDIR)\attset.h    $(TABLEDIR)\table.h
HDRS     = $(HDRS_1)               $(UTILDIR)\error.h      \
           $(UTILDIR)\tabread.h    nposs.h
OBJS     = $(UTILDIR)\arrays.obj   $(UTILDIR)\escape.obj   \
           $(UTILDIR)\tabread.obj  $(UTILDIR)\tabwrite.obj \
           $(UTILDIR)\scanner.obj  $(TABLEDIR)\attset1.obj \
           $(TABLEDIR)\attset2.obj $(TABLEDIR)\attset3.obj \
           $(TABLEDIR)\table1.obj  $(TABLEDIR)\tab2ro.obj
NPI_O    = $(OBJS) $(TABLEDIR)\table3.obj npc_ind.obj npi.obj
NPX_O    = $(OBJS) npc_exec.obj npx.obj
PRGS     = npi.exe npx.exe

#-----------------------------------------------------------------------
# Build Programs
#-----------------------------------------------------------------------
all:          $(PRGS)

npi.exe:      $(NPI_O) nposs.mak
	$(LD) $(LDFLAGS) $(NPI_O) $(LIBS) /out:$@

npx.exe:      $(NPX_O) nposs.mak
	$(LD) $(LDFLAGS) $(NPX_O) $(LIBS) /out:$@

#-----------------------------------------------------------------------
# Main Programs
#-----------------------------------------------------------------------
npi.obj:      $(HDRS)
npi.obj:      npi.c nposs.mak
	$(CC) $(CFLAGS) $(INCS) npi.c /Fo$@

npx.obj:      $(HDRS) $(UTILDIR)\tabwrite.h
npx.obj:      npx.c nposs.mak
	$(CC) $(CFLAGS) $(INCS) npx.c /Fo$@

#-----------------------------------------------------------------------
# Naive Bayes Classifier Management
#-----------------------------------------------------------------------
npc_ind.obj:  $(HDRS_1)
npc_ind.obj:  nposs.c nposs.mak
	$(CC) $(CFLAGS) $(INCS) /D NPC_INDUCE nposs.c /Fo$@

npc_exec.obj: $(HDRS_1)
npc_exec.obj: nposs.c nposs.mak
	$(CC) $(CFLAGS) $(INCS) /D NPC_PARSE nposs.c /Fo$@

#-----------------------------------------------------------------------
# External Modules
#-----------------------------------------------------------------------
$(UTILDIR)\arrays.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak arrays.obj
	cd $(THISDIR)
$(UTILDIR)\symtab.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak symtab.obj
	cd $(THISDIR)
$(UTILDIR)\escape.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak escape.obj
	cd $(THISDIR)
$(UTILDIR)\tabread.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak tabread.obj
	cd $(THISDIR)
$(UTILDIR)\tabwrite.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak tabwrite.obj
	cd $(THISDIR)
$(UTILDIR)\scanner.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak scanner.obj
	cd $(THISDIR)
$(TABLEDIR)\attset1.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak attset1.obj
	cd $(THISDIR)
$(TABLEDIR)\attset2.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak attset2.obj
	cd $(THISDIR)
$(TABLEDIR)\attset3.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak attset3.obj
	cd $(THISDIR)
$(TABLEDIR)\table1.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak table1.obj
	cd $(THISDIR)
$(TABLEDIR)\tab2ro.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak tab2ro.obj
	cd $(THISDIR)
$(TABLEDIR)\table3.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak table3.obj
	cd $(THISDIR)

#-----------------------------------------------------------------------
# Install
#-----------------------------------------------------------------------
install:
	-@copy *.exe ..\..\..\bin

#-----------------------------------------------------------------------
# Clean up
#-----------------------------------------------------------------------
clean:
	$(MAKE) /f nposs.mak localclean
	cd $(UTILDIR)
	$(MAKE) /f util.mak clean
	cd $(TABLEDIR)
	$(MAKE) /f table.mak localclean
	cd $(THISDIR)

localclean:
	-@erase /Q *~ *.obj *.idb *.pch $(PRGS)
